@@ -14,13 +14,12 @@ BEGIN {
 		require APR::Pool;
 		require Apache2::RequestRec;
 	}
-
 }
 
 {
     no strict;
     @ISA = qw(DynaLoader);
-    $VERSION = '0.15';
+    $VERSION = '0.16';
     __PACKAGE__->bootstrap($VERSION);
 }
 
@@ -36,7 +35,7 @@ sub init {
 
 sub handler {
     my $r = shift;
-Updates from 
+
     init();
 
     {
@@ -186,7 +185,7 @@ perldebug(1)
 
 Originally written by Doug MacEachern
 
-Currently maintained by Frank Wiles <frank@wiles.org> 
+Currently maintained by Dirk Lindner <lze@cpan.org>
 
 
 =head1 LICENSE 
