@@ -132,7 +132,7 @@ sub DB {
     # evals which do not define subroutines will disappear.
     no strict 'refs';
     $DB::listings{$filename} = \@{"main::_<$filename"} if 
-	defined(@{"main::_<$filename"});
+	(@{"main::_<$filename"});
     use strict 'refs';
 
     my $delta = $DB::done - $DB::start;
@@ -231,7 +231,7 @@ sub sub {
     if (defined($DB::sub{$DB::sub})) {
 	my($m,$s) = ($DB::sub{$DB::sub} =~ /.+(?=:)|[^:-]+/g);
 	$DB::profiles{$m}->[$s]++;
-	$DB::listings{$m} = \@{"main::_<$m"} if defined(@{"main::_<$m"});
+	$DB::listings{$m} = \@{"main::_<$m"} if (@{"main::_<$m"});
     }
     goto &$DB::sub;
 }
